==> mypy-boto3-marketplace-catalog-1.28.15.tar.gz: mypy-boto3-marketplace-catalog-1.28.15/mypy_boto3_marketplace_catalog/type_defs.py <==
"""
Type annotations for marketplace-catalog service type definitions.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_marketplace_catalog/type_defs/)

Usage::

    ```python
    from mypy_boto3_marketplace_catalog.type_defs import CancelChangeSetRequestRequestTypeDef

    data: CancelChangeSetRequestRequestTypeDef = {...}
    ```
"""
import sys
from typing import Dict, List, Sequence

from .literals import ChangeStatusType, FailureCodeType, OwnershipTypeType, SortOrderType

if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "CancelChangeSetRequestRequestTypeDef",
    "ResponseMetadataTypeDef",
    "ChangeSetSummaryListItemTypeDef",
    "EntityTypeDef",
    "ErrorDetailTypeDef",
    "TagTypeDef",
    "DeleteResourcePolicyRequestRequestTypeDef",
    "DescribeChangeSetRequestRequestTypeDef",
    "DescribeEntityRequestRequestTypeDef",
    "EntitySummaryTypeDef",
    "FilterTypeDef",
    "GetResourcePolicyRequestRequestTypeDef",
    "PaginatorConfigTypeDef",
    "SortTypeDef",
    "ListTagsForResourceRequestRequestTypeDef",
    "PutResourcePolicyRequestRequestTypeDef",
    "UntagResourceRequestRequestTypeDef",
    "CancelChangeSetResponseTypeDef",
    "DescribeEntityResponseTypeDef",
    "GetResourcePolicyResponseTypeDef",
    "StartChangeSetResponseTypeDef",
    "ListChangeSetsResponseTypeDef",
    "ChangeSummaryTypeDef",
    "ChangeTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "TagResourceRequestRequestTypeDef",
    "ListEntitiesResponseTypeDef",
    "ListChangeSetsRequestListChangeSetsPaginateTypeDef",
    "ListChangeSetsRequestRequestTypeDef",
    "ListEntitiesRequestListEntitiesPaginateTypeDef",
    "ListEntitiesRequestRequestTypeDef",
    "DescribeChangeSetResponseTypeDef",
    "StartChangeSetRequestRequestTypeDef",
)

CancelChangeSetRequestRequestTypeDef = TypedDict(
    "CancelChangeSetRequestRequestTypeDef",
    {
        "Catalog": str,
        "ChangeSetId": str,
    },
)

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

ChangeSetSummaryListItemTypeDef = TypedDict(
    "ChangeSetSummaryListItemTypeDef",
    {
        "ChangeSetId": str,
        "ChangeSetArn": str,
        "ChangeSetName": str,
        "StartTime": str,
        "EndTime": str,
        "Status": ChangeStatusType,
        "EntityIdList": List[str],
        "FailureCode": FailureCodeType,
    },
    total=False,
)

_RequiredEntityTypeDef = TypedDict(
    "_RequiredEntityTypeDef",
    {
        "Type": str,
    },
)
_OptionalEntityTypeDef = TypedDict(
    "_OptionalEntityTypeDef",
    {
        "Identifier": str,
    },
    total=False,
)


class EntityTypeDef(_RequiredEntityTypeDef, _OptionalEntityTypeDef):
    pass


ErrorDetailTypeDef = TypedDict(
    "ErrorDetailTypeDef",
    {
        "ErrorCode": str,
        "ErrorMessage": str,
    },
    total=False,
)

TagTypeDef = TypedDict(
    "TagTypeDef",
    {
        "Key": str,
        "Value": str,
    },
)

DeleteResourcePolicyRequestRequestTypeDef = TypedDict(
    "DeleteResourcePolicyRequestRequestTypeDef",
    {
        "ResourceArn": str,
    },
)

DescribeChangeSetRequestRequestTypeDef = TypedDict(
    "DescribeChangeSetRequestRequestTypeDef",
    {
        "Catalog": str,
        "ChangeSetId": str,
    },
)

DescribeEntityRequestRequestTypeDef = TypedDict(
    "DescribeEntityRequestRequestTypeDef",
    {
        "Catalog": str,
        "EntityId": str,
    },
)

EntitySummaryTypeDef = TypedDict(
    "EntitySummaryTypeDef",
    {
        "Name": str,
        "EntityType": str,
        "EntityId": str,
        "EntityArn": str,
        "LastModifiedDate": str,
        "Visibility": str,
    },
    total=False,
)

FilterTypeDef = TypedDict(
    "FilterTypeDef",
    {
        "Name": str,
        "ValueList": Sequence[str],
    },
    total=False,
)

GetResourcePolicyRequestRequestTypeDef = TypedDict(
    "GetResourcePolicyRequestRequestTypeDef",
    {
        "ResourceArn": str,
    },
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": int,
        "PageSize": int,
        "StartingToken": str,
    },
    total=False,
)

SortTypeDef = TypedDict(
    "SortTypeDef",
    {
        "SortBy": str,
        "SortOrder": SortOrderType,
    },
    total=False,
)

ListTagsForResourceRequestRequestTypeDef = TypedDict(
    "ListTagsForResourceRequestRequestTypeDef",
    {
        "ResourceArn": str,
    },
)

PutResourcePolicyRequestRequestTypeDef = TypedDict(
    "PutResourcePolicyRequestRequestTypeDef",
    {
        "ResourceArn": str,
        "Policy": str,
    },
)

UntagResourceRequestRequestTypeDef = TypedDict(
    "UntagResourceRequestRequestTypeDef",
    {
        "ResourceArn": str,
        "TagKeys": Sequence[str],
    },
)

CancelChangeSetResponseTypeDef = TypedDict(
    "CancelChangeSetResponseTypeDef",
    {
        "ChangeSetId": str,
        "ChangeSetArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

DescribeEntityResponseTypeDef = TypedDict(
    "DescribeEntityResponseTypeDef",
    {
        "EntityType": str,
        "EntityIdentifier": str,
        "EntityArn": str,
        "LastModifiedDate": str,
        "Details": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetResourcePolicyResponseTypeDef = TypedDict(
    "GetResourcePolicyResponseTypeDef",
    {
        "Policy": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

StartChangeSetResponseTypeDef = TypedDict(
    "StartChangeSetResponseTypeDef",
    {
        "ChangeSetId": str,
        "ChangeSetArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListChangeSetsResponseTypeDef = TypedDict(
    "ListChangeSetsResponseTypeDef",
    {
        "ChangeSetSummaryList": List[ChangeSetSummaryListItemTypeDef],
        "NextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ChangeSummaryTypeDef = TypedDict(
    "ChangeSummaryTypeDef",
    {
        "ChangeType": str,
        "Entity": EntityTypeDef,
        "Details": str,
        "ErrorDetailList": List[ErrorDetailTypeDef],
        "ChangeName": str,
    },
    total=False,
)

_RequiredChangeTypeDef = TypedDict(
    "_RequiredChangeTypeDef",
    {
        "ChangeType": str,
        "Entity": EntityTypeDef,
        "Details": str,
    },
)
_OptionalChangeTypeDef = TypedDict(
    "_OptionalChangeTypeDef",
    {
        "EntityTags": Sequence[TagTypeDef],
        "ChangeName": str,
    },
    total=False,
)


class ChangeTypeDef(_RequiredChangeTypeDef, _OptionalChangeTypeDef):
    pass


ListTagsForResourceResponseTypeDef = TypedDict(
    "ListTagsForResourceResponseTypeDef",
    {
        "ResourceArn": str,
        "Tags": List[TagTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

TagResourceRequestRequestTypeDef = TypedDict(
    "TagResourceRequestRequestTypeDef",
    {
        "ResourceArn": str,
        "Tags": Sequence[TagTypeDef],
    },
)

ListEntitiesResponseTypeDef = TypedDict(
    "ListEntitiesResponseTypeDef",
    {
        "EntitySummaryList": List[EntitySummaryTypeDef],
        "NextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

_RequiredListChangeSetsRequestListChangeSetsPaginateTypeDef = TypedDict(
    "_RequiredListChangeSetsRequestListChangeSetsPaginateTypeDef",
    {
        "Catalog": str,
    },
)
_OptionalListChangeSetsRequestListChangeSetsPaginateTypeDef = TypedDict(
    "_OptionalListChangeSetsRequestListChangeSetsPaginateTypeDef",
    {
        "FilterList": Sequence[FilterTypeDef],
        "Sort": SortTypeDef,
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)


class ListChangeSetsRequestListChangeSetsPaginateTypeDef(
    _RequiredListChangeSetsRequestListChangeSetsPaginateTypeDef,
    _OptionalListChangeSetsRequestListChangeSetsPaginateTypeDef,
):
    pass


_RequiredListChangeSetsRequestRequestTypeDef = TypedDict(
    "_RequiredListChangeSetsRequestRequestTypeDef",
    {
        "Catalog": str,
    },
)
_OptionalListChangeSetsRequestRequestTypeDef = TypedDict(
    "_OptionalListChangeSetsRequestRequestTypeDef",
    {
        "FilterList": Sequence[FilterTypeDef],
        "Sort": SortTypeDef,
        "MaxResults": int,
        "NextToken": str,
    },
    total=False,
)


class ListChangeSetsRequestRequestTypeDef(
    _RequiredListChangeSetsRequestRequestTypeDef, _OptionalListChangeSetsRequestRequestTypeDef
):
    pass


_RequiredListEntitiesRequestListEntitiesPaginateTypeDef = TypedDict(
    "_RequiredListEntitiesRequestListEntitiesPaginateTypeDef",
    {
        "Catalog": str,
        "EntityType": str,
    },
)
_OptionalListEntitiesRequestListEntitiesPaginateTypeDef = TypedDict(
    "_OptionalListEntitiesRequestListEntitiesPaginateTypeDef",
    {
        "FilterList": Sequence[FilterTypeDef],
        "Sort": SortTypeDef,
        "OwnershipType": OwnershipTypeType,
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)


class ListEntitiesRequestListEntitiesPaginateTypeDef(
    _RequiredListEntitiesRequestListEntitiesPaginateTypeDef,
    _OptionalListEntitiesRequestListEntitiesPaginateTypeDef,
):
    pass


_RequiredListEntitiesRequestRequestTypeDef = TypedDict(
    "_RequiredListEntitiesRequestRequestTypeDef",
    {
        "Catalog": str,
        "EntityType": str,
    },
)
_OptionalListEntitiesRequestRequestTypeDef = TypedDict(
    "_OptionalListEntitiesRequestRequestTypeDef",
    {
        "FilterList": Sequence[FilterTypeDef],
        "Sort": SortTypeDef,
        "NextToken": str,
        "MaxResults": int,
        "OwnershipType": OwnershipTypeType,
    },
    total=False,
)


class ListEntitiesRequestRequestTypeDef(
    _RequiredListEntitiesRequestRequestTypeDef, _OptionalListEntitiesRequestRequestTypeDef
):
    pass


DescribeChangeSetResponseTypeDef = TypedDict(
    "DescribeChangeSetResponseTypeDef",
    {
        "ChangeSetId": str,
        "ChangeSetArn": str,
        "ChangeSetName": str,
        "StartTime": str,
        "EndTime": str,
        "Status": ChangeStatusType,
        "FailureCode": FailureCodeType,
        "FailureDescription": str,
        "ChangeSet": List[ChangeSummaryTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

_RequiredStartChangeSetRequestRequestTypeDef = TypedDict(
    "_RequiredStartChangeSetRequestRequestTypeDef",
    {
        "Catalog": str,
        "ChangeSet": Sequence[ChangeTypeDef],
    },
)
_OptionalStartChangeSetRequestRequestTypeDef = TypedDict(
    "_OptionalStartChangeSetRequestRequestTypeDef",
    {
        "ChangeSetName": str,
        "ClientRequestToken": str,
        "ChangeSetTags": Sequence[TagTypeDef],
    },
    total=False,
)


class StartChangeSetRequestRequestTypeDef(
    _RequiredStartChangeSetRequestRequestTypeDef, _OptionalStartChangeSetRequestRequestTypeDef
):
    pass

==> mypy-boto3-marketplace-catalog-1.28.36.post1.tar.gz: mypy-boto3-marketplace-catalog-1.28.36.post1/mypy_boto3_marketplace_catalog/type_defs.py <==
"""
Type annotations for marketplace-catalog service type definitions.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_marketplace_catalog/type_defs/)

Usage::

    ```python
    from mypy_boto3_marketplace_catalog.type_defs import CancelChangeSetRequestRequestTypeDef

    data: CancelChangeSetRequestRequestTypeDef = ...
    ```
"""
import sys
from typing import Any, Dict, List, Sequence, Union

from .literals import ChangeStatusType, FailureCodeType, OwnershipTypeType, SortOrderType

if sys.version_info >= (3, 12):
    from typing import NotRequired
else:
    from typing_extensions import NotRequired
if sys.version_info >= (3, 12):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "CancelChangeSetRequestRequestTypeDef",
    "ResponseMetadataTypeDef",
    "ChangeSetSummaryListItemTypeDef",
    "EntityTypeDef",
    "ErrorDetailTypeDef",
    "TagTypeDef",
    "DeleteResourcePolicyRequestRequestTypeDef",
    "DescribeChangeSetRequestRequestTypeDef",
    "DescribeEntityRequestRequestTypeDef",
    "DictOrStrTypeDef",
    "EntitySummaryTypeDef",
    "FilterTypeDef",
    "GetResourcePolicyRequestRequestTypeDef",
    "PaginatorConfigTypeDef",
    "SortTypeDef",
    "ListTagsForResourceRequestRequestTypeDef",
    "UntagResourceRequestRequestTypeDef",
    "CancelChangeSetResponseTypeDef",
    "DescribeEntityResponseTypeDef",
    "GetResourcePolicyResponseTypeDef",
    "StartChangeSetResponseTypeDef",
    "ListChangeSetsResponseTypeDef",
    "ChangeSummaryTypeDef",
    "ChangeTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "TagResourceRequestRequestTypeDef",
    "PutResourcePolicyRequestRequestTypeDef",
    "ListEntitiesResponseTypeDef",
    "ListChangeSetsRequestListChangeSetsPaginateTypeDef",
    "ListChangeSetsRequestRequestTypeDef",
    "ListEntitiesRequestListEntitiesPaginateTypeDef",
    "ListEntitiesRequestRequestTypeDef",
    "DescribeChangeSetResponseTypeDef",
    "StartChangeSetRequestRequestTypeDef",
)

CancelChangeSetRequestRequestTypeDef = TypedDict(
    "CancelChangeSetRequestRequestTypeDef",
    {
        "Catalog": str,
        "ChangeSetId": str,
    },
)

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

ChangeSetSummaryListItemTypeDef = TypedDict(
    "ChangeSetSummaryListItemTypeDef",
    {
        "ChangeSetId": NotRequired[str],
        "ChangeSetArn": NotRequired[str],
        "ChangeSetName": NotRequired[str],
        "StartTime": NotRequired[str],
        "EndTime": NotRequired[str],
        "Status": NotRequired[ChangeStatusType],
        "EntityIdList": NotRequired[List[str]],
        "FailureCode": NotRequired[FailureCodeType],
    },
)

EntityTypeDef = TypedDict(
    "EntityTypeDef",
    {
        "Type": str,
        "Identifier": NotRequired[str],
    },
)

ErrorDetailTypeDef = TypedDict(
    "ErrorDetailTypeDef",
    {
        "ErrorCode": NotRequired[str],
        "ErrorMessage": NotRequired[str],
    },
)

TagTypeDef = TypedDict(
    "TagTypeDef",
    {
        "Key": str,
        "Value": str,
    },
)

DeleteResourcePolicyRequestRequestTypeDef = TypedDict(
    "DeleteResourcePolicyRequestRequestTypeDef",
    {
        "ResourceArn": str,
    },
)

DescribeChangeSetRequestRequestTypeDef = TypedDict(
    "DescribeChangeSetRequestRequestTypeDef",
    {
        "Catalog": str,
        "ChangeSetId": str,
    },
)

DescribeEntityRequestRequestTypeDef = TypedDict(
    "DescribeEntityRequestRequestTypeDef",
    {
        "Catalog": str,
        "EntityId": str,
    },
)

DictOrStrTypeDef = Union[str, Dict[str, Any]]
EntitySummaryTypeDef = TypedDict(
    "EntitySummaryTypeDef",
    {
        "Name": NotRequired[str],
        "EntityType": NotRequired[str],
        "EntityId": NotRequired[str],
        "EntityArn": NotRequired[str],
        "LastModifiedDate": NotRequired[str],
        "Visibility": NotRequired[str],
    },
)

FilterTypeDef = TypedDict(
    "FilterTypeDef",
    {
        "Name": NotRequired[str],
        "ValueList": NotRequired[Sequence[str]],
    },
)

GetResourcePolicyRequestRequestTypeDef = TypedDict(
    "GetResourcePolicyRequestRequestTypeDef",
    {
        "ResourceArn": str,
    },
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": NotRequired[int],
        "PageSize": NotRequired[int],
        "StartingToken": NotRequired[str],
    },
)

SortTypeDef = TypedDict(
    "SortTypeDef",
    {
        "SortBy": NotRequired[str],
        "SortOrder": NotRequired[SortOrderType],
    },
)

ListTagsForResourceRequestRequestTypeDef = TypedDict(
    "ListTagsForResourceRequestRequestTypeDef",
    {
        "ResourceArn": str,
    },
)

UntagResourceRequestRequestTypeDef = TypedDict(
    "UntagResourceRequestRequestTypeDef",
    {
        "ResourceArn": str,
        "TagKeys": Sequence[str],
    },
)

CancelChangeSetResponseTypeDef = TypedDict(
    "CancelChangeSetResponseTypeDef",
    {
        "ChangeSetId": str,
        "ChangeSetArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

DescribeEntityResponseTypeDef = TypedDict(
    "DescribeEntityResponseTypeDef",
    {
        "EntityType": str,
        "EntityIdentifier": str,
        "EntityArn": str,
        "LastModifiedDate": str,
        "Details": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetResourcePolicyResponseTypeDef = TypedDict(
    "GetResourcePolicyResponseTypeDef",
    {
        "Policy": Dict[str, Any],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

StartChangeSetResponseTypeDef = TypedDict(
    "StartChangeSetResponseTypeDef",
    {
        "ChangeSetId": str,
        "ChangeSetArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListChangeSetsResponseTypeDef = TypedDict(
    "ListChangeSetsResponseTypeDef",
    {
        "ChangeSetSummaryList": List[ChangeSetSummaryListItemTypeDef],
        "NextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ChangeSummaryTypeDef = TypedDict(
    "ChangeSummaryTypeDef",
    {
        "ChangeType": NotRequired[str],
        "Entity": NotRequired[EntityTypeDef],
        "Details": NotRequired[str],
        "ErrorDetailList": NotRequired[List[ErrorDetailTypeDef]],
        "ChangeName": NotRequired[str],
    },
)

ChangeTypeDef = TypedDict(
    "ChangeTypeDef",
    {
        "ChangeType": str,
        "Entity": EntityTypeDef,
        "Details": str,
        "EntityTags": NotRequired[Sequence[TagTypeDef]],
        "ChangeName": NotRequired[str],
    },
)

ListTagsForResourceResponseTypeDef = TypedDict(
    "ListTagsForResourceResponseTypeDef",
    {
        "ResourceArn": str,
        "Tags": List[TagTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

TagResourceRequestRequestTypeDef = TypedDict(
    "TagResourceRequestRequestTypeDef",
    {
        "ResourceArn": str,
        "Tags": Sequence[TagTypeDef],
    },
)

PutResourcePolicyRequestRequestTypeDef = TypedDict(
    "PutResourcePolicyRequestRequestTypeDef",
    {
        "ResourceArn": str,
        "Policy": DictOrStrTypeDef,
    },
)

ListEntitiesResponseTypeDef = TypedDict(
    "ListEntitiesResponseTypeDef",
    {
        "EntitySummaryList": List[EntitySummaryTypeDef],
        "NextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListChangeSetsRequestListChangeSetsPaginateTypeDef = TypedDict(
    "ListChangeSetsRequestListChangeSetsPaginateTypeDef",
    {
        "Catalog": str,
        "FilterList": NotRequired[Sequence[FilterTypeDef]],
        "Sort": NotRequired[SortTypeDef],
        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
    },
)

ListChangeSetsRequestRequestTypeDef = TypedDict(
    "ListChangeSetsRequestRequestTypeDef",
    {
        "Catalog": str,
        "FilterList": NotRequired[Sequence[FilterTypeDef]],
        "Sort": NotRequired[SortTypeDef],
        "MaxResults": NotRequired[int],
        "NextToken": NotRequired[str],
    },
)

ListEntitiesRequestListEntitiesPaginateTypeDef = TypedDict(
    "ListEntitiesRequestListEntitiesPaginateTypeDef",
    {
        "Catalog": str,
        "EntityType": str,
        "FilterList": NotRequired[Sequence[FilterTypeDef]],
        "Sort": NotRequired[SortTypeDef],
        "OwnershipType": NotRequired[OwnershipTypeType],
        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
    },
)

ListEntitiesRequestRequestTypeDef = TypedDict(
    "ListEntitiesRequestRequestTypeDef",
    {
        "Catalog": str,
        "EntityType": str,
        "FilterList": NotRequired[Sequence[FilterTypeDef]],
        "Sort": NotRequired[SortTypeDef],
        "NextToken": NotRequired[str],
        "MaxResults": NotRequired[int],
        "OwnershipType": NotRequired[OwnershipTypeType],
    },
)

DescribeChangeSetResponseTypeDef = TypedDict(
    "DescribeChangeSetResponseTypeDef",
    {
        "ChangeSetId": str,
        "ChangeSetArn": str,
        "ChangeSetName": str,
        "StartTime": str,
        "EndTime": str,
        "Status": ChangeStatusType,
        "FailureCode": FailureCodeType,
        "FailureDescription": str,
        "ChangeSet": List[ChangeSummaryTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

StartChangeSetRequestRequestTypeDef = TypedDict(
    "StartChangeSetRequestRequestTypeDef",
    {
        "Catalog": str,
        "ChangeSet": Sequence[ChangeTypeDef],
        "ChangeSetName": NotRequired[str],
        "ClientRequestToken": NotRequired[str],
        "ChangeSetTags": NotRequired[Sequence[TagTypeDef]],
    },
)
